* {
  box-sizing: border-box;
}

input,
select,
textarea,
button {
  font: #{$body-font-size}/1.4 $body-font;
}

body {
  font: #{$body-font-size}/1.4 $body-font;
  color: $brand-gray-dark;
  background-color: #fff;
}

a {
  color: $brand-blue;
  text-decoration: none;

  &:hover,
  &:active {
    text-decoration: underline;
  }
}

// Horizontal lines
//
// TODO-MDO: Remove `.rule` from everywhere and replace with `<hr>`s
hr,
.rule {
  height: 0;
  margin: 15px 0;
  overflow: hidden;
  background: transparent;
  border: 0;
  border-bottom: 1px solid #ddd;
  @include clearfix();
}
