html {
  font-size: 0.8rem;
}
body {
  padding-top: 1.5em;
  padding-bottom: 1.5em;
}

$light: #ddd;
@import "bootstrap/bootstrap";

.flash {
  margin-bottom:15px;
}

.row + .row {
  margin-top: 1.5em;
}

